==> quassel_0.5.1.orig.tar.gz: quassel-0.5.1.orig/src/qtui/awaylogview.h <==
/***************************************************************************
 *   Copyright (C) 2005-08 by the Quassel Project                          *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef AWAYLOGVIEW_H
#define AWAYLOGVIEW_H

#include "chatmonitorview.h"

class AwayLogFilter;

class AwayLogView : public ChatMonitorView {
  Q_OBJECT

public:
  AwayLogView(AwayLogFilter *filter, QWidget *parent = 0);
  virtual void addActionsToMenu(QMenu *menu, const QPointF &pos);
};

#endif //AWAYLOGVIEW_H

==> quassel_0.13.1.orig.tar.gz: quassel-0.13.1/src/qtui/awaylogview.h <==
/***************************************************************************
 *   Copyright (C) 2005-2019 by the Quassel Project                        *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef AWAYLOGVIEW_H
#define AWAYLOGVIEW_H

#include "chatmonitorview.h"

class AwayLogFilter;

class AwayLogView : public ChatMonitorView
{
    Q_OBJECT

public:
    AwayLogView(AwayLogFilter *filter, QWidget *parent = 0);
    virtual void addActionsToMenu(QMenu *menu, const QPointF &pos);
};


#endif //AWAYLOGVIEW_H
